@@ -21,6 +21,12 @@ fi
 set -- ${DESTDIR:-}/usr/share/postgresql/$PGVERSION/pljava/pljava-examples-*.jar
 EXJAR="$1"
 
+JAVA_VERSION=$(java --version | head -n1 | grep -Eo '[0-9]+' | head -n1)
+if [ "$JAVA_VERSION" -ge 20 ]; then
+  # tell Java 20+ that we use the Java security architecture (https://github.com/tada/pljava/wiki/JEP-411)
+  psql -c "ALTER USER $PGUSER SET pljava.vmoptions = '-Djava.security.manager=allow'"
+fi
+
 psql -c "ALTER USER $PGUSER SET check_function_bodies = off"
 psql -c "CREATE EXTENSION pljava"
 psql -c "SELECT sqlj.install_jar('file:$EXJAR', 'examples', true)"
